# CrashReport


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [readonly] 
**url** | **str** |  | [readonly] 
**created_dt** | **datetime** |  | [readonly] 
**updated_dt** | **datetime** |  | [readonly] 
**description** | **str** |  | [optional] 
**email** | **str** |  | [optional] 
**os_version** | **str** |  | [optional] 
**os_logs** | **str** |  | [optional] 
**browser_version** | **str** |  | [optional] 
**browser_logs** | **str** |  | [optional] 
**serial** | **str** |  | [optional] 
**posthog_session** | **str** |  | [optional] 
**status** | [**CrashReportStatusEnum**](CrashReportStatusEnum.md) |  | [optional] 
**support_comment** | **str** |  | [optional] 
**user** | **int** |  | [readonly] 
**pi** | **int** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


